"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class AdRecord {
    constructor(obj) {
        if (!obj.title || obj.title.length > 100) {
            throw new errors_1.ValidationError('Nazwa postu nie może być pusta, ani przekraczać 100 znaków.');
        }
        if (!obj.description || obj.description.length < 0) {
            throw new errors_1.ValidationError('Opis postu nie może być pusty.');
        }
        this.id = obj.id;
        this.title = obj.title;
        this.description = obj.description;
        this.createdAt = obj.createdAt;
    }
    static getOneArticle(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `blog` WHERE `id` = :id", {
                id,
            });
            return results.length === 0 ? null : new AdRecord(results[0]);
        });
    }
    insertArticle() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
                if (!this.createdAt) {
                    this.createdAt = new Date().toISOString().slice(0, 10);
                }
                yield db_1.pool.execute("INSERT INTO `blog`(`id`, `title`, `description`, `createdAt`) VALUES(:id, :title, :description, :createdAt)", this);
                return [this.id, this.createdAt];
            }
        });
    }
    ;
    static listAllArticle() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `blog` ORDER BY `createdAt` DESC"));
            return results.map(obj => new AdRecord(obj));
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `blog` WHERE `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad.record.js.map